@@ -12,12 +12,15 @@ pub struct PyCircuitItems {
 
 pub static PY_CIRCUIT_ITEMS: GILLazyPy<PyCircuitItems> = GILLazyPy::new_py(|py| {
     let module = PyModule::from_code(
-            py,
-            "from interp.circuit import computational_node, constant; import interp.circuit.interop_rust.interop_rust as interop; import interp.circuit.circuit_compiler.util as circ_compiler_util",
-            "py_circuit_interop.py",
-            "py_circuit_interop",
-        )
-        .unwrap(); // TODO: fail more gracefully?
+        py,
+        include_str!(concat!(
+            env!("CARGO_MANIFEST_DIR"),
+            "/py_circuit_interop.py"
+        )),
+        concat!(env!("CARGO_MANIFEST_DIR"), "/py_circuit_interop.py"),
+        "py_circuit_interop",
+    )
+    .unwrap(); // TODO: fail more gracefully?
 
     let get = |s: &str| module.getattr(s).unwrap().into();
 
